;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "citar-denote" "20251220.2230"
  "Minor mode integrating Citar and Denote."
  '((emacs  "28.1")
    (citar  "1.4")
    (denote "4.1")
    (dash   "2.19.1"))
  :url "https://github.com/pprevos/citar-denote"
  :commit "0c04d022ff2c992ec233938a14cbfc4f4914c431"
  :revdesc "0c04d022ff2c"
  :authors '(("Peter Prevos" . "peter@prevos.net"))
  :maintainers '(("Peter Prevos" . "peter@prevos.net")))
